aiocodingame
============
.. image:: https://img.shields.io/pypi/v/aiocodingame?color=blue
   :target: https://pypi.python.org/pypi/aiocodingame
   :alt: PyPI version info
.. image:: https://img.shields.io/pypi/pyversions/aiocodingame?color=orange
   :target: https://pypi.python.org/pypi/aiocodingame
   :alt: PyPI supported Python versions
.. image:: https://img.shields.io/pypi/dm/aiocodingame
   :target: https://pypi.python.org/pypi/aiocodingame
   :alt: PyPI downloads
.. image:: https://readthedocs.org/projects/aiocodingame/badge/?version=latest
   :target: https://aiocodingame.readthedocs.io/en/latest/
   :alt: Documentation Status
.. image:: https://img.shields.io/github/license/takos22/aiocodingame?color=brightgreen
   :alt: License: MIT
.. image:: https://img.shields.io/discord/754028526079836251.svg?label=&logo=discord&logoColor=ffffff&color=7389D8&labelColor=6A7EC2
   :target: https://discord.gg/8HgtN6E
   :alt: Discord support server

Asynchronous pythonic wrapper for the undocumented CodinGame API.


Installing
----------

**Python 3.6 or higher is required.**

Run the following command:

.. code:: sh

    pip install aiocodingame


Contribute
----------

- `Source Code <https://github.com/takos22/aiocodingame>`_
- `Issue Tracker <https://github.com/takos22/aiocodingame/issues>`_


Support
-------

If you are having issues, please let me know by joining the support server at https://discord.gg/8HgtN6E

License
-------

The project is licensed under the MIT license.

Links
------

- `PyPi <https://pypi.org/project/aiocodingame/>`_
- `Documentation <https://aiocodingame.readthedocs.io/en/latest/index.html>`_
- `Discord support server <https://discord.gg/8HgtN6E>`_
